@@ -347,7 +347,7 @@ gtk_widget_set_sensitive (colorpicker, FALSE);
 
 static void cb_about (AppletWidget *applet, gpointer data)
 {
-    GtkWidget *about;
+    static GtkWidget *about = NULL;
     static const gchar *authors[] = {
 			    /* languages which use font encodings that can't
 			     * display spanish '' should use 'n' instead */
@@ -355,6 +355,12 @@ static void cb_about (AppletWidget *applet, gpointer data)
 			    NULL
     };
 
+    if (about != NULL)
+    {
+        gdk_window_show(about->window);
+        gdk_window_raise(about->window);
+	return;
+    }
 #ifdef ENABLE_NLS
     {
 	int i=0;
@@ -370,6 +376,8 @@ static void cb_about (AppletWidget *applet, gpointer data)
                     	     _("An analog clock similar to that in CDE panel."),
                     	     NULL);
 
+    gtk_signal_connect( GTK_OBJECT(about), "destroy",
+		        GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about );
     gtk_widget_show (about);
 
     return;
@@ -640,6 +648,15 @@ static gint update_clock (gpointer data)
     data = NULL;
 }
 
+static void
+help_cb (AppletWidget *applet, gpointer data)
+{
+	static GnomeHelpMenuEntry help_entry = { 
+		"anotherclock_applet", "index.html"
+	};
+	gnome_help_display (NULL, &help_entry);
+}
+
 /*****************
  * Main function *
  *****************/
@@ -700,19 +717,22 @@ int main (int argc, char *argv[])
 	                GTK_SIGNAL_FUNC(applet_back_change), clk.area);
     gtk_signal_connect(GTK_OBJECT(applet),"change_pixel_size",
 		       GTK_SIGNAL_FUNC(change_pixel_size), NULL);
-    applet_widget_register_stock_callback (APPLET_WIDGET(applet),
-					   "about",
-					   GNOME_STOCK_MENU_ABOUT,
-					   _("About..."),
-					   cb_about,
-					   NULL);
     applet_widget_register_stock_callback (APPLET_WIDGET(applet),
 					   "properties",
 					   GNOME_STOCK_MENU_PROP,
 					   _("Properties..."),
 					   cb_properties,
 					   NULL);
-
+    applet_widget_register_stock_callback (APPLET_WIDGET(applet),
+					   "help",
+					   GNOME_STOCK_PIXMAP_HELP,
+					   _("Help"), help_cb, NULL);
+    applet_widget_register_stock_callback (APPLET_WIDGET(applet),
+					   "about",
+					   GNOME_STOCK_MENU_ABOUT,
+					   _("About..."),
+					   cb_about,
+					   NULL);
     /* applet main loop */
     applet_widget_gtk_main ();
           
