@@ -791,14 +791,16 @@ make_new_battery_applet (const gchar *goad_id)
    * hiding/showing the entire graph mode.
    */
   bat->graph_frame = gtk_frame_new (NULL);
-  gtk_frame_set_shadow_type (GTK_FRAME (bat->graph_frame), GTK_SHADOW_IN);
+  gtk_frame_set_shadow_type (GTK_FRAME (bat->graph_frame), 
+			     GTK_SHADOW_ETCHED_IN);
 
   /*
    * The 'readout frame' is the root widget of the entire readout
    * mode.
    */
   bat->readout_frame = gtk_frame_new (NULL);
-  gtk_frame_set_shadow_type (GTK_FRAME (bat->readout_frame), GTK_SHADOW_IN);
+  gtk_frame_set_shadow_type (GTK_FRAME (bat->readout_frame), 
+			     GTK_SHADOW_ETCHED_IN);
      
   gtk_box_pack_start_defaults (GTK_BOX (root), bat->graph_frame);
   gtk_box_pack_start_defaults (GTK_BOX (root), bat->readout_frame);
@@ -925,7 +927,7 @@ make_new_battery_applet (const gchar *goad_id)
   applet_widget_register_stock_callback (APPLET_WIDGET (bat->applet),
 					 "properties",
 					 GNOME_STOCK_MENU_PROP,
-					 ("Properties..."),
+					 _("Properties..."),
 					 battery_properties_window,
 					 bat);
 
@@ -974,7 +976,10 @@ make_new_battery_applet (const gchar *goad_id)
 void
 destroy_about (GtkWidget *w, gpointer data)
 {
-  /* BatteryData *bat = data; */
+   BatteryData *bat = data; 
+
+   bat->about_box = NULL;
+
   return;
   w = NULL;
   data = NULL;
@@ -986,6 +991,12 @@ about_cb (AppletWidget *widget, gpointer data)
   BatteryData *bat = data;
   char *authors[2];
   
+  if (bat->about_box != NULL)
+  {
+    gdk_window_show(bat->about_box->window);
+    gdk_window_raise(bat->about_box->window);
+    return;
+  }
   authors[0] = "Nat Friedman <nat@nat.org>";
   authors[1] = NULL;
 
