@@ -57,6 +57,7 @@ glibtop_fsusage fsu;
 glibtop_mountlist mountlist;
 glibtop_mountentry *mount_list;
 
+static gboolean is_realized = FALSE;
 static GtkWidget *diskusage;
 static GtkWidget *my_applet;
 GtkWidget *disp;
@@ -75,7 +76,12 @@ void create_gc(void);
 void start_timer(void);
 void change_filesystem_cb (AppletWidget *applet, gpointer data);
 void add_mount_list_menu_items (void);
+#if 0
 static void browse_cb (AppletWidget *widget, gpointer data);
+#endif
+static void update_cb (AppletWidget *widget, gpointer data);
+int diskusage_get_best_size_v (void);
+int diskusage_get_best_size_h (void);
 
 GtkWidget *diskusage_widget(void);
 
@@ -85,10 +91,118 @@ guint num_mpoints;
 
 int timer_index=-1;
 
+int diskusage_get_best_size_v ()
+{
+	GdkFont* my_font;
+	int string_height;
+	int du_pie_gap;
+	int du_mountpoint_x;
+	int du_freespace_x;
+	int total_height;
+	int pie_width;		/* width+height of piechart */
+
+
+	my_font = gdk_font_load      ("fixed");
+
+	if (summary_info.pixel_size <= PIXEL_SIZE_TINY) {
+		du_pie_gap = du_mountpoint_x = du_freespace_x = 0;
+	} else if (summary_info.pixel_size <= PIXEL_SIZE_SMALL) {
+		du_pie_gap = du_mountpoint_x = du_freespace_x = 1;
+	} else {
+		du_pie_gap = DU_PIE_GAP;
+		du_mountpoint_x = DU_MOUNTPOINT_X;
+		du_freespace_x = DU_FREESPACE_X;
+	}
+	
+	pie_width = summary_info.pixel_size - du_pie_gap;
+
+	string_height = gdk_string_height (my_font, "MP: ");
+
+	total_height = DU_FREESPACE2_Y_VERT + pie_width + du_pie_gap +
+		string_height * 4;
+
+	return total_height;
+}
+
+int diskusage_get_best_size_h ()
+{
+	GdkFont* my_font;
+	int string_width;
+	int cur_width;
+	int du_pie_gap;
+	int total_width;
+	int pie_width;		/* width+height of piechart */
+	gchar avail_buf[100];	/* used for mountpoint text */
+	char *text;
+	int i;
+
+	glibtop_mountlist my_mountlist;
+	glibtop_mountentry *my_mount_list;
+
+
+	my_font = gdk_font_load      ("fixed");
+
+	if (summary_info.pixel_size <= PIXEL_SIZE_TINY) {
+		du_pie_gap = 0;
+	} else if (summary_info.pixel_size <= PIXEL_SIZE_SMALL) {
+		du_pie_gap = 1;
+	} else {
+		du_pie_gap = DU_PIE_GAP;
+	}
+	
+	pie_width = summary_info.pixel_size - du_pie_gap;
+
+	string_width = 0;
+
+
+	memset (&my_mountlist, 0, sizeof (glibtop_mountlist));
+	my_mount_list = glibtop_get_mountlist (&my_mountlist, 1);
+	
+	for (i = 0; i < mountlist.number; i++) {
+	    text = my_mount_list [i].mountdir;
+	    strcpy(avail_buf, "MP: ");
+	    strcat(avail_buf, text);
+
+	    cur_width = gdk_string_width (my_font, avail_buf);
+
+	    if (cur_width > string_width)
+		string_width = cur_width;
+	}
+
+	glibtop_free (my_mount_list);
+
+	cur_width = gdk_string_width (my_font, "av: 9999.999 MB");
+	if (cur_width > string_width)
+	    string_width = cur_width;
+
+	total_width = pie_width + du_pie_gap + DU_FREESPACE_HOR_X * 2 +
+		string_width + du_pie_gap;
+
+	return total_width;
+}
+
 
 void diskusage_resize ()
 {
-	gtk_widget_set_usize(disp, props.width, props.height);
+	if ((summary_info.orient == ORIENT_LEFT) ||
+	    (summary_info.orient == ORIENT_RIGHT))
+		if (props.best_size)
+			gtk_widget_set_usize (my_applet, summary_info.pixel_size,
+					      diskusage_get_best_size_v ());
+		else
+			gtk_widget_set_usize (my_applet, summary_info.pixel_size,
+					      props.size);
+	else
+		if (props.best_size)
+			gtk_widget_set_usize (my_applet,
+					      diskusage_get_best_size_h (),
+					      summary_info.pixel_size);
+		else
+			gtk_widget_set_usize (my_applet, props.size,
+					      summary_info.pixel_size);
+
+	if (is_realized)
+		update_values ();
 }
 
 /* Get list of currently mounted filesystems. */
@@ -97,7 +211,7 @@ void diskusage_read ()
 	unsigned int i;
 
 	if (mount_list != NULL)
-		free (mount_list);
+		glibtop_free (mount_list);
 	mount_list = glibtop_get_mountlist (&mountlist, 0);
 	
 	assert (mount_list != NULL);
@@ -119,6 +233,11 @@ int draw_h(void)
 	GdkFont* my_font;
 	char *text;
 	unsigned free_space;
+	int du_pie_gap;
+	int du_mountpoint_y;
+	int du_freespace_y;
+	int string_height;
+	int vert_spacing;
 	double ratio;		/* % of space used */
 	int pie_width;		/* width+height of piechart */
 	int pie_spacing;	/* space between piechart and border */
@@ -130,11 +249,26 @@ int draw_h(void)
 
 	
 	sel_fs = summary_info.selected_filesystem;
+
+	if (summary_info.pixel_size <= PIXEL_SIZE_TINY) {
+		du_pie_gap = du_mountpoint_y = du_freespace_y = 0;
+	} else if (summary_info.pixel_size <= PIXEL_SIZE_SMALL) {
+		du_pie_gap = du_mountpoint_y = du_freespace_y = 1;
+	} else {
+		du_pie_gap = DU_PIE_GAP;
+		du_mountpoint_y = DU_MOUNTPOINT_Y;
+		du_freespace_y = DU_FREESPACE_Y;
+	}
 	
-	pie_width = disp->allocation.height - DU_PIE_GAP;
-	pie_spacing = DU_PIE_GAP / 2;
+	pie_width = disp->allocation.height - du_pie_gap;
+	pie_spacing = du_pie_gap / 2;
 
+	string_height = gdk_string_height (my_font, "MP: ");
 
+	vert_spacing = disp->allocation.height -
+		(string_height * 2 + du_pie_gap);
+	if (vert_spacing < 0) vert_spacing = 0;
+	vert_spacing /= 3;
 
 	/* Mountpoint text */
 	text = mount_list [sel_fs].mountdir;
@@ -155,7 +289,21 @@ int draw_h(void)
 #else
 	free_space = fsu.bavail; /* Free blocks available to non-superuser. */
 #endif
-	g_snprintf (avail_buf2, sizeof(avail_buf2), "av: %u", free_space);
+
+	if (free_space > 1048471142) /* 9999 MB */
+	    g_snprintf (avail_buf2,sizeof(avail_buf2),"av: %.3f GB",
+			(float)free_space / 1073741824.0);
+	else if (free_space > 10238976) /* 9999 kB */
+	    g_snprintf (avail_buf2,sizeof(avail_buf2),"av: %.3f MB",
+			(float)free_space / 1048576.0);
+	else if (free_space > 9999) /* 9999 Bytes */
+	    g_snprintf (avail_buf2,sizeof(avail_buf2),"av: %.3f kB",
+			free_space / 1024.0);
+	else
+	    g_snprintf (avail_buf2,sizeof(avail_buf2),"av: %u",
+			free_space);
+
+	/* g_snprintf (avail_buf2, sizeof(avail_buf2), "av: %u", free_space); */
 
 
 	gdk_gc_set_foreground( gc, &bcolor );
@@ -172,13 +320,13 @@ int draw_h(void)
 	
 	/* draw text strings */
 	gdk_draw_string(pixmap, my_font, gc,
-			DU_MOUNTPOINT_X + pie_width + DU_PIE_GAP, 
-			DU_MOUNTPOINT_Y,
+			DU_MOUNTPOINT_HOR_X + pie_width + du_pie_gap, 
+			string_height + vert_spacing,
 			avail_buf1);
 	
 	gdk_draw_string(pixmap, my_font, gc,
-			DU_FREESPACE_X + pie_width + DU_PIE_GAP, 
-			DU_FREESPACE_Y,
+			DU_FREESPACE_HOR_X + pie_width + du_pie_gap, 
+			2 * (string_height + vert_spacing),
 			avail_buf2);
 	
 	/* Draw % usage Pie */
@@ -233,6 +381,10 @@ int draw_v(void)
 	char *text;
 	unsigned free_space;
 	double ratio;		/* % of space used */
+	int du_pie_gap;
+	int du_mountpoint_x;
+	int du_freespace_x;
+	int vert_spacing;	/* vertical spacing */
 	int pie_width;		/* width+height of piechart */
 	int pie_spacing;	/* space between piechart and border */
 	int sel_fs;		/* # of selected filesystem */
@@ -243,11 +395,24 @@ int draw_v(void)
 
 	
 	sel_fs = summary_info.selected_filesystem;
+
+	if (summary_info.pixel_size <= PIXEL_SIZE_TINY) {
+		du_pie_gap = du_mountpoint_x = du_freespace_x = 0;
+	} else if (summary_info.pixel_size <= PIXEL_SIZE_SMALL) {
+		du_pie_gap = du_mountpoint_x = du_freespace_x = 1;
+	} else {
+		du_pie_gap = DU_PIE_GAP;
+		du_mountpoint_x = DU_MOUNTPOINT_X;
+		du_freespace_x = DU_FREESPACE_X;
+	}
 	
-	pie_width = disp->allocation.width - DU_PIE_GAP;
-	pie_spacing = DU_PIE_GAP / 2;
-
+	pie_width = disp->allocation.width - du_pie_gap;
+	pie_spacing = du_pie_gap / 2;
 
+	vert_spacing = disp->allocation.height -
+		(DU_FREESPACE2_Y_VERT + pie_width + du_pie_gap);
+	if (vert_spacing < 0) vert_spacing = 0;
+	vert_spacing /= 2;
 
 	/* Mountpoint text, part 1*/
 
@@ -273,13 +438,15 @@ int draw_v(void)
 	
 	/* draw text strings */
 	gdk_draw_string(pixmap, my_font, gc,
-			DU_MOUNTPOINT_X, 
-			DU_MOUNTPOINT_Y_VERT + pie_width + DU_PIE_GAP,
+			du_mountpoint_x, 
+			DU_MOUNTPOINT_Y_VERT + pie_width + du_pie_gap +
+			vert_spacing,
 			avail_buf1);
 	
 	gdk_draw_string(pixmap, my_font, gc,
-			DU_FREESPACE_X, 
-			DU_FREESPACE_Y_VERT + pie_width + DU_PIE_GAP,
+			du_freespace_x, 
+			DU_FREESPACE_Y_VERT + pie_width + du_pie_gap +
+			vert_spacing,
 			avail_buf2);
 	
 	/* Mountpoint text, part 2*/
@@ -287,7 +454,6 @@ int draw_v(void)
 
 	strcpy(avail_buf1, text);
 
-
 	/* Free Space text, part2*/		        
 	glibtop_get_fsusage (&fsu, mount_list [sel_fs].mountdir);
 
@@ -300,17 +466,59 @@ int draw_v(void)
 #else
 	free_space = fsu.bavail; /* Free blocks available to non-superuser. */
 #endif
-	g_snprintf (avail_buf2,sizeof(avail_buf2),"%u", free_space);
+	if (summary_info.pixel_size <= PIXEL_SIZE_STANDARD) {
+		if (free_space > 1048471142) /* 9999 MB */
+			g_snprintf (avail_buf2,sizeof(avail_buf2),"%uG",
+				    free_space >> 30);
+		else if (free_space > 10238976) /* 9999 kB */
+			g_snprintf (avail_buf2,sizeof(avail_buf2),"%uM",
+				    free_space >> 20);
+		else if (free_space > 9999) /* 9999 Bytes */
+			g_snprintf (avail_buf2,sizeof(avail_buf2),"%uk",
+				    free_space >> 10);
+		else
+			g_snprintf (avail_buf2,sizeof(avail_buf2),"%u",
+				    free_space);
+
+	} else if (summary_info.pixel_size <= PIXEL_SIZE_LARGE) {
+		if (free_space > 1048471142) /* 9999 MB */
+			g_snprintf (avail_buf2,sizeof(avail_buf2),"%.1f GB",
+				    (float)free_space / 1073741824.0);
+		else if (free_space > 10238976) /* 9999 kB */
+			g_snprintf (avail_buf2,sizeof(avail_buf2),"%.1f MB",
+				    (float)free_space / 1048576.0);
+		else if (free_space > 9999) /* 9999 Bytes */
+			g_snprintf (avail_buf2,sizeof(avail_buf2),"%.1f kB",
+				    free_space / 1024.0);
+		else
+			g_snprintf (avail_buf2,sizeof(avail_buf2),"%u",
+				    free_space);
+	} else {
+		if (free_space > 1048471142) /* 9999 MB */
+			g_snprintf (avail_buf2,sizeof(avail_buf2),"%.3f GB",
+				    (float)free_space / 1073741824.0);
+		else if (free_space > 10238976) /* 9999 kB */
+			g_snprintf (avail_buf2,sizeof(avail_buf2),"%.3f MB",
+				    (float)free_space / 1048576.0);
+		else if (free_space > 9999) /* 9999 Bytes */
+			g_snprintf (avail_buf2,sizeof(avail_buf2),"%.3f kB",
+				    free_space / 1024.0);
+		else
+			g_snprintf (avail_buf2,sizeof(avail_buf2),"%u",
+				    free_space);
+	}
 
 	/* draw text strings 2nd part*/
 	gdk_draw_string(pixmap, my_font, gc,
-			DU_MOUNTPOINT_X, 
-			DU_MOUNTPOINT2_Y_VERT + pie_width + DU_PIE_GAP,
+			du_mountpoint_x, 
+			DU_MOUNTPOINT2_Y_VERT + pie_width + du_pie_gap +
+			vert_spacing,
 			avail_buf1);
 	
 	gdk_draw_string(pixmap, my_font, gc,
-			DU_FREESPACE_X, 
-			DU_FREESPACE2_Y_VERT + pie_width + DU_PIE_GAP,
+			du_freespace_x, 
+			DU_FREESPACE2_Y_VERT + pie_width + du_pie_gap +
+			vert_spacing,
 			avail_buf2);
 	
 	/* Draw % usage Pie */
@@ -328,7 +536,8 @@ int draw_v(void)
 	gdk_draw_arc (pixmap,
 			gc,
 			1,		/* filled = true */
-			pie_spacing, pie_spacing, pie_width, pie_width,
+			pie_spacing, pie_spacing + (vert_spacing / 2),
+		        pie_width, pie_width,
 			90 * 64,
 			- (360 * ratio) * 64);
 
@@ -336,12 +545,11 @@ int draw_v(void)
 	gdk_draw_arc (pixmap,
 			gc,
 			1,		/* filled = true */
-			pie_spacing, pie_spacing, pie_width, pie_width,
+			pie_spacing, pie_spacing + (vert_spacing / 2),
+		        pie_width, pie_width,
 			(90 + 360 * (1 - ratio)) * 64,
 			- (360 * (1 -ratio)) * 64);
 
-	
-	
 	gdk_draw_pixmap(disp->window,
 		disp->style->fg_gc[GTK_WIDGET_STATE(disp)],
 	        pixmap,
@@ -358,12 +566,11 @@ int draw_v(void)
 
 void draw(void)
 {
-
-	if (summary_info.orient == ORIENT_LEFT || summary_info.orient == ORIENT_RIGHT)
+	if (summary_info.orient == ORIENT_LEFT ||
+	    summary_info.orient == ORIENT_RIGHT)
 		draw_v();
 	else
 		draw_h();
-
 }
 
 
@@ -407,47 +614,30 @@ void start_timer( void )
 
 
 static void
-applet_change_orient(GtkWidget *w, PanelOrientType o, gpointer data)
+applet_change_orient(AppletWidget *w, PanelOrientType o, gpointer data)
 {
-
-	guint tmp;
-
-	summary_info.orient = o;
-
-	/*
-	 * swap width <-> height of applet, when width is > then height
-	 * and vertical panel, or when it is < on horizontal panel
-	 */
-
-	if (o == ORIENT_LEFT || o == ORIENT_RIGHT) {
-		if (props.width > props.height) {
-			tmp = props.width;
-			props.width = props.height;
-			props.height = tmp;
-		}
-	} else {
-		if (props.width < props.height) {
-			tmp = props.width;
-			props.width = props.height;
-			props.height = tmp;
-		}
-	}
-
+	summary_info.orient = applet_widget_get_panel_orient (w);
 
 	diskusage_resize();
-
-	return;
-	w = NULL;
-        data = NULL;
 }
 
+static void
+applet_change_pixel_size(AppletWidget *w, int size, gpointer data)
+{
+	summary_info.pixel_size = applet_widget_get_panel_pixel_size (w);
+
+	diskusage_resize();
+}
+
+
 
 /*
  * read new filesystem-info, and call draw
  */
 static gint update_values (void)
 {
-
+	if (!is_realized)
+		return FALSE;
 
 	diskusage_read ();
 
@@ -482,6 +672,9 @@ static gint diskusage_configure(GtkWidget *widget, GdkEventConfigure *event)
                 0, 0,
                 disp->allocation.width,
                 disp->allocation.height);
+
+	update_values ();
+
 	return TRUE;
 	event = NULL;
 } 
@@ -676,6 +869,8 @@ void update_mount_list_menu_items () {
 
 }
 
+#if 0
+
 static void browse_cb (AppletWidget *widget, gpointer data)
 {
         const char *buf[2];
@@ -700,7 +895,12 @@ static void browse_cb (AppletWidget *widget, gpointer data)
 	data = NULL;
 }
 
+#endif
 
+static void update_cb (AppletWidget *widget, gpointer data)
+{
+	diskusage_resize ();
+}
 
 GtkWidget *diskusage_widget(void)
 {
@@ -746,10 +946,15 @@ GtkWidget *diskusage_widget(void)
 	gtk_container_add( GTK_CONTAINER(event_box), box );
 	gtk_container_add( GTK_CONTAINER(frame), event_box);
 	
+	summary_info.orient = applet_widget_get_panel_orient (APPLET_WIDGET (my_applet));
+	summary_info.pixel_size = applet_widget_get_panel_pixel_size (APPLET_WIDGET (my_applet));
+
+	is_realized = TRUE;
+        
 	diskusage_resize();
 
 	start_timer();
-        
+
         gtk_widget_show_all(frame);
 	
 
@@ -758,13 +963,58 @@ GtkWidget *diskusage_widget(void)
 }
 
 
+static void about_cb (AppletWidget *widget, gpointer data)
+{
+	static GtkWidget *about = NULL;
+	const gchar *authors[8];
+
+	if (about != NULL)
+	{
+		gdk_window_show(about->window);
+		gdk_window_raise(about->window);
+		return;
+	}
+
+	authors[0] = "Bruno Widmann <bwidmann@tks.fh-sbg.ac.at>";
+	authors[1] = "Martin Baulig <martin@home-of-linux.org>";
+	authors[2] = "Dave Finton <dfinton@d.umn.edu>";
+	authors[3] = NULL;
+
+
+        about = gnome_about_new
+		(_("Disk Usage Applet"), VERSION,
+		 "(C) 1999",
+		 authors,
+		 _("Released under the GNU general public license.\n"
+		   "Monitors the amount of space in use and available on your "
+		   "disk drives."),
+		 NULL);
+	gtk_signal_connect (GTK_OBJECT (about), "destroy",
+			    GTK_SIGNAL_FUNC (gtk_widget_destroyed), &about);
+
+	gtk_widget_show (about);
+}
+
+static void 
+show_help_cb (AppletWidget *applet, gpointer data)
+{
+	static GnomeHelpMenuEntry help_entry = { NULL, "index.html"};
+
+	help_entry.name = gnome_app_id;
+    
+	gnome_help_display (NULL, &help_entry);
+}
+
 static gint applet_save_session(GtkWidget *widget, char *privcfgpath, char *globcfgpath, gpointer data)
 {
 	save_properties(privcfgpath,&props);
+
+	gnome_config_sync();
+	/* you need to use the drop_all here since we're all writing to
+	   one file, without it, things might not work too well */
+	gnome_config_drop_all ();
+
 	return FALSE;
-	widget = NULL;
-	data = NULL;
-	globcfgpath = NULL;
 }
 
 int main(int argc, char **argv)
@@ -792,6 +1042,10 @@ int main(int argc, char **argv)
 			   GTK_SIGNAL_FUNC(applet_change_orient),
 			   NULL);
 
+	gtk_signal_connect(GTK_OBJECT(applet),"change_pixel_size",
+			   GTK_SIGNAL_FUNC(applet_change_pixel_size),
+			   NULL);
+
         applet_widget_add( APPLET_WIDGET(applet), diskusage );
 
 
@@ -813,13 +1067,34 @@ int main(int argc, char **argv)
 					      properties,
 					      NULL);
 
+#if 0
 	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
                                               "browse",
                                               GNOME_STOCK_MENU_OPEN,
                                               _("Browse..."),
                                               browse_cb,
                                               NULL);
+#endif
 
+	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
+                                              "update",
+                                              GNOME_STOCK_MENU_REFRESH,
+                                              _("Update..."),
+                                              update_cb,
+                                              NULL);
+
+	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
+					      "help",
+					      GNOME_STOCK_PIXMAP_HELP,
+					      _("Help"),
+					      show_help_cb,
+					      NULL);
+
+	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
+					      "about",
+					      GNOME_STOCK_MENU_ABOUT,
+					      _("About..."),
+					      about_cb, NULL);
 	applet_widget_gtk_main();
 
 
