@@ -111,12 +111,19 @@ static void dnd_init(DriveData *dd);
 
 static void about_cb (AppletWidget *widget, gpointer data)
 {
-	GtkWidget *about;
+	static GtkWidget *about = NULL;
 	const gchar *authors[2];
 
 	authors[0] = "John Ellis <johne@bellatlantic.net>";
 	authors[1] = NULL;
 
+	if (about != NULL)
+	{
+		gdk_window_show(about->window);
+		gdk_window_raise(about->window);
+		return;
+	}
+
         about = gnome_about_new ( _("Drive Mount Applet"), VERSION,
 			"(C) 1999",
 			authors,
@@ -124,6 +131,8 @@ static void about_cb (AppletWidget *widget, gpointer data)
 			"Mounts and Unmounts drives."
 			"."),
 			NULL);
+	gtk_signal_connect(GTK_OBJECT(about), "destroy",
+	                   GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about);
 	gtk_widget_show (about);
 	return;
 	widget = NULL;
@@ -145,17 +154,11 @@ static void browse_cb (AppletWidget *widget, gpointer data)
 	buf[0] = dd->mount_point;
 	buf[1] = NULL;
 
-/*	I assume the first (commented out) call is mor correct, but:
- *	use  "IDL:GNOME/FileManagerWindow:1.0"  ?
- *	how do we correctly construct this string? In the event version != 1.0 ?
- */
+	/* FIXME browse menu item is broken here. */
+	goad_server_activate_with_repo_id(NULL,
+					  "IDL:GNOME/FileManager/Window:1.0",
+					  0, buf);
 
-/*	goad_server_activate_with_repo_id(NULL, "IDL:GNOME/FileManagerWindow:1.0",
-			GOAD_ACTIVATE_REMOTE | GOAD_ACTIVATE_ASYNC, buf);
-*/
-
-	goad_server_activate_with_id(NULL, "gmc_filemanager_window",
-			0, buf);
 	return;
 	widget = NULL;
 }
@@ -246,8 +249,9 @@ static void update_pixmap(DriveData *dd, gint t)
 	if (hint > SIZEHINT_MAX) hint = SIZEHINT_MAX; /* maximum size we can scale to */
 	hint -= 6; /* buttons have border of 3 >>> FIXME!, broken for themes ? */
 
+/*
 	printf("dm applet check: orient=%d size=%d scale=%d\n", dd->orient, dd->sizehint, dd->scale_applet);
-
+*/
 	if (dd->device_pixmap > icon_list_count - 1) dd->device_pixmap = 0;
 
 	if (dd->device_pixmap < 0 && (!dd->custom_icon_in || !dd->custom_icon_out) ) dd->device_pixmap = 0;
@@ -422,6 +426,14 @@ static gint mount_cb(GtkWidget *widget, gpointer data)
 	GString *str;
 	gint check = device_is_mounted(dd);
 
+	/* Stop the user from displaying zillions of error messages */
+	if (dd->error_dialog)
+	{
+		gdk_window_show(dd->error_dialog->window);
+		gdk_window_raise(dd->error_dialog->window);
+		return FALSE;
+	}
+
 	if (!check)
 		g_snprintf(command_line, sizeof(command_line),
 			   "mount %s 2>&1", dd->mount_point);
@@ -454,7 +466,9 @@ static gint mount_cb(GtkWidget *widget, gpointer data)
 		g_string_prepend(str, _("\" reported:\n"));
 		g_string_prepend(str, command_line);
 		g_string_prepend(str, _("Drivemount command failed.\n\""));
-		gnome_warning_dialog(str->str);
+		dd->error_dialog = gnome_warning_dialog(str->str);
+		gtk_signal_connect(GTK_OBJECT(dd->error_dialog), "destroy",
+				   GTK_SIGNAL_FUNC(gtk_widget_destroyed), &dd->error_dialog);
 		}
 
 	g_string_free(str, TRUE);
@@ -605,6 +619,7 @@ static DriveData * create_drive_widget(GtkWidget *applet)
 	dd->autofs_friendly = FALSE;
 	dd->custom_icon_in = NULL;
 	dd->custom_icon_out = NULL;
+	dd->error_dialog = NULL; 
 
 	dd->orient = applet_widget_get_panel_orient(APPLET_WIDGET(applet));
 
@@ -614,9 +629,6 @@ static DriveData * create_drive_widget(GtkWidget *applet)
 	dd->sizehint = SIZEHINT_DEFAULT;
 #endif
 
-#warning FIXME: someone please please look into why orient and size are zero at this point
-	printf("dm applet test: orient=%d size=%d\n", dd->orient, dd->sizehint);
-
 	property_load(APPLET_WIDGET(applet)->privcfgpath, dd);
 
 	dd->button=gtk_button_new();
