@@ -89,12 +89,21 @@ static void about(AppletWidget *applet, gpointer data)
 {
     static const char *authors[] = { "spoon <spoon@ix.netcom.com>",
                                      "dres <dres@debian.org", NULL };
-    GtkWidget *about_box;
+    static GtkWidget *about_box = NULL;
+
+    if (about_box != NULL)
+    {
+    	gdk_window_show(about_box->window);
+        gdk_window_raise(about_box->window);
+        return;
+    }
 
     about_box = gnome_about_new(_("GNotes!"), VERSION,
                                 _("Copyright (C) 1998-1999 spoon <spoon@ix.netcom.com> \nCopyright (C) 1999 dres <dres@debian.org>"),
                                 authors,
                                 _("Create sticky notes on your screen."), NULL);
+    gtk_signal_connect(GTK_OBJECT(about_box), "destroy",
+                       GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about_box);
 
     gtk_widget_show(about_box);
 }
