@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.13 2000/02/17 06:34:18 spapadim Exp $ */
+/* $Id: gweather-applet.c,v 1.15 2000/02/29 21:13:14 jberkman Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -181,18 +181,23 @@ void gweather_applet_create (int argc, char *argv[])
 
     gtk_widget_set_events(gweather_applet, gtk_widget_get_events(gweather_applet) | \
                           GDK_BUTTON_PRESS_MASK);
-    applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet), "about",
-                                           GNOME_STOCK_MENU_ABOUT, _("About..."),
-                                           about_cb, NULL);
-    applet_widget_register_callback (APPLET_WIDGET(gweather_applet), "help",
-                                     _("Help"),
-                                     help_cb, NULL);
+
     applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet), "preferences",
                                            GNOME_STOCK_MENU_PREF, _("Properties..."),
                                            pref_cb, NULL);
+    applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet), 
+					   "help",
+					   GNOME_STOCK_PIXMAP_HELP,
+					   _("Help"),
+					   help_cb, NULL);
+
+    applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet), "about",
+                                           GNOME_STOCK_MENU_ABOUT, _("About..."),
+                                           about_cb, NULL);
     applet_widget_register_stock_callback (APPLET_WIDGET(gweather_applet), "update",
 					   GNOME_STOCK_MENU_REFRESH, _("Update"),
 					   update_cb, NULL);
+
 #ifdef HAVE_SAVE_SESSION_SIGNAL
     gtk_signal_connect (GTK_OBJECT(gweather_applet), "save_session",
                        GTK_SIGNAL_FUNC(save_session_cb), NULL);
@@ -211,7 +216,7 @@ void gweather_applet_create (int argc, char *argv[])
     tooltips = gtk_tooltips_new();
 
     frame = gtk_frame_new(NULL);
-    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_IN);
+    gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_IN);
     gtk_widget_set_usize(frame, 26, 48);
     gtk_widget_show(frame);
 
