@@ -180,7 +180,7 @@ setMixer(gint vol)
 /*g_message("Saving mixer value of %d",tvol);*/
 	ioctl(mixerfd, MIXER_WRITE(SOUND_MIXER_VOLUME), &tvol);
 #endif
-#if SUN_API
+#ifdef SUN_API
  	audio_info_t ainfo;
 	AUDIO_INITINFO (&ainfo);
  	ainfo.play.gain = vol;
@@ -686,7 +686,12 @@ main(int argc, char **argv)
 	applet_widget_init("mixer_applet", VERSION, argc, argv,
 				    NULL, 0, NULL);
 
+#ifdef OSS_API
 	openMixer("/dev/mixer");
+#endif
+#ifdef SUN_API
+	openMixer("/dev/audioctl");
+#endif
 
 	applet = applet_widget_new("mixer_applet");
 	if (!applet)
