@@ -12,14 +12,10 @@
 #include <glibtop/cpu.h>
 #include <glibtop/mem.h>
 #include <glibtop/swap.h>
+#include <glibtop/loadavg.h>
 
 #include "linux-proc.h"
 
-#define NCPUSTATES 4
-
-static long cp_time[NCPUSTATES];
-static long last[NCPUSTATES];
-
 static unsigned needed_cpu_flags =
 (1 << GLIBTOP_CPU_USER) +
 (1 << GLIBTOP_CPU_IDLE);
@@ -30,10 +26,12 @@ static unsigned needed_mem_flags =
 
 static unsigned needed_swap_flags = 0;
 
+static unsigned needed_loadavg_flags =
+(1 << GLIBTOP_LOADAVG_LOADAVG);
+
 void
-GetLoad (int Maximum, int data [4])
+GetLoad (int Maximum, int data [4], LoadGraph *g)
 {
-    static int init = 0;
     int usr, nice, sys, free;
     int total;
 
@@ -43,27 +41,27 @@ GetLoad (int Maximum, int data [4])
 	
     assert ((cpu.flags & needed_cpu_flags) == needed_cpu_flags);
     
-    cp_time [0] = cpu.user;
-    cp_time [1] = cpu.nice;
-    cp_time [2] = cpu.sys;
-    cp_time [3] = cpu.idle;
+    g->cpu_time [0] = cpu.user;
+    g->cpu_time [1] = cpu.nice;
+    g->cpu_time [2] = cpu.sys;
+    g->cpu_time [3] = cpu.idle;
 
-    if (!init) {
-	memcpy (last, cp_time, sizeof (last));
-	init = 1;
+    if (!g->cpu_initialized) {
+	memcpy (g->cpu_last, g->cpu_time, sizeof (g->cpu_last));
+	g->cpu_initialized = 1;
     }
 
-    usr  = cp_time [0] - last [0];
-    nice = cp_time [1] - last [1];
-    sys  = cp_time [2] - last [2];
-    free = cp_time [3] - last [3];
+    usr  = g->cpu_time [0] - g->cpu_last [0];
+    nice = g->cpu_time [1] - g->cpu_last [1];
+    sys  = g->cpu_time [2] - g->cpu_last [2];
+    free = g->cpu_time [3] - g->cpu_last [3];
 
     total = usr + nice + sys + free;
 
-    last [0] = cp_time [0];
-    last [1] = cp_time [1];
-    last [2] = cp_time [2];
-    last [3] = cp_time [3];
+    g->cpu_last [0] = g->cpu_time [0];
+    g->cpu_last [1] = g->cpu_time [1];
+    g->cpu_last [2] = g->cpu_time [2];
+    g->cpu_last [3] = g->cpu_time [3];
 
     if (!total) total = Maximum;
 
@@ -79,7 +77,7 @@ GetLoad (int Maximum, int data [4])
 }
 
 void
-GetMemory (int Maximum, int data [4])
+GetMemory (int Maximum, int data [4], LoadGraph *g)
 {
     int user, shared, buffer, free;
 
@@ -103,7 +101,7 @@ GetMemory (int Maximum, int data [4])
 }
 
 void
-GetSwap (int Maximum, int data [2])
+GetSwap (int Maximum, int data [2], LoadGraph *g)
 {
     int used, free;
 
@@ -128,7 +126,47 @@ GetSwap (int Maximum, int data [2])
 }
 
 void
-GetNet (int Maximum, int data [4])
+GetLoadAvg (int Maximum, int data [2], LoadGraph *g)
+{
+    float used, free;
+    float max_loadavg = 10.0;
+    int index;
+
+    glibtop_loadavg loadavg;
+	
+    glibtop_get_loadavg (&loadavg);
+	
+    assert ((loadavg.flags & needed_loadavg_flags) == needed_loadavg_flags);
+
+    switch (g->prop_data->loadavg_type) {
+    case LOADAVG_1:
+	index = 0;
+	break;
+    case LOADAVG_5:
+	index = 1;
+	break;
+    case LOADAVG_15:
+	index = 2;
+	break;
+    default:
+	g_assert_not_reached ();
+    }
+
+    if (g->prop_data_ptr->adj_data [2])
+	max_loadavg = (float) g->prop_data_ptr->adj_data [2];
+
+    if (loadavg.loadavg [index] > max_loadavg)
+	loadavg.loadavg [index] = max_loadavg;
+
+    used    = (loadavg.loadavg [index]) / max_loadavg;
+    free    = (max_loadavg - loadavg.loadavg [index]) / max_loadavg;
+
+    data [0] = rint ((float) Maximum * used);
+    data [1] = rint ((float) Maximum * free);
+}
+
+void
+GetNet (int Maximum, int data [4], LoadGraph *g)
 {
 #define SLIP_COUNT	0
 #define PPP_COUNT	1
