@@ -28,7 +28,7 @@ void showHelp (AppletWidget * applet, gpointer data);
 void
 cb_about (AppletWidget * widget, gpointer data)
 {
-  GtkWidget *about;
+  static GtkWidget *about = NULL;
   GtkWidget *my_url;
   static const char *authors[] =
     { "Tom Gilbert <gilbertt@tomgilbert.freeserve.co.uk>",
@@ -36,6 +36,13 @@ cb_about (AppletWidget * widget, gpointer data)
     "The Sirius Cybernetics Corporation <Ursa-minor>", NULL
   };
 
+  if (about != NULL)
+  {
+  	gdk_window_show(about->window);
+	gdk_window_raise(about->window);
+	return;	
+  }
+
   about = gnome_about_new
     (_ ("Screen-Shooter Applet"),
      VERSION,
@@ -46,6 +53,8 @@ cb_about (AppletWidget * widget, gpointer data)
 		 "or an area (click and drag to select a rectangle.)\n"
 		 "The right/bottom button will grab the entire desktop.\n"
 		 "Share and Enjoy ;)"), NULL);
+  gtk_signal_connect( GTK_OBJECT(about), "destroy",
+		      GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about );
 
   my_url = gnome_href_new ("http://www.tomgilbert.freeserve.co.uk",
 			   "Visit the author's Website");
@@ -89,6 +98,7 @@ properties_save (gchar * path, gpointer data)
 			   options.script_filename);
   gnome_config_set_string ("screenshooter/thumb_filename",
 			   options.thumb_filename);
+  gnome_config_set_string ("screenshooter/app", options.app);
   gnome_config_set_bool ("screenshoter/decoration", options.decoration);
   gnome_config_set_bool ("screenshoter/monochrome", options.monochrome);
   gnome_config_set_bool ("screenshoter/negate", options.negate);
@@ -491,6 +501,8 @@ cb_properties_dialog (AppletWidget * widget, gpointer data)
   pref_hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
   gtk_box_pack_start (GTK_BOX (pref_vbox_2), pref_hbox, FALSE, FALSE, 0);
   gtk_widget_show (pref_hbox);
+  /* The % sign screws overt xgettext ;) */
+  /* xgettext:no-c-format */
   label = gtk_label_new (_
 			 ("Filetype is determined from filename suffix.\n"
 			  "Default filetype (if no extension or unrecognised extension) "
