@@ -49,10 +49,16 @@ static WebControl WC = {
 static void
 about_cb (AppletWidget *widget, gpointer data)
 {
-	GtkWidget *about;
+	static GtkWidget *about = NULL;
 	static const gchar *authors[2] =
 	{"Garrett Smith <gsmith@serv.net>", NULL};
 
+	if (about != NULL)
+	{
+		gdk_window_show(about->window);
+		gdk_window_raise(about->window);
+		return;
+	}
 	about = gnome_about_new (_("The Web Browser Controller"),
 			VERSION,
 			"(C) 1998 the Free Software Foundation",
@@ -62,6 +68,8 @@ about_cb (AppletWidget *widget, gpointer data)
 			  "interface.  Hopefully later more webrowsers "
 			  "will be supported."),
 			NULL);
+	gtk_signal_connect( GTK_OBJECT(about), "destroy",
+			    GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about );
 	gtk_widget_show (about);
 
 	return;
@@ -205,10 +213,17 @@ apply_cb(GnomePropertyBox * pb, gint page, gpointer data)
 static void
 properties_cb (AppletWidget *widget, gpointer data)
 {
-	GtkWidget * pb;
+	static GtkWidget * pb = NULL;
 	GtkWidget * vbox;
 	GtkWidget *urlcheck, *launchcheck;
 
+	/* Stop the property box from being opened multiple times */
+	if (pb != NULL)
+	{
+		gdk_window_show( GTK_WIDGET(pb)->window );
+		gdk_window_raise( GTK_WIDGET(pb)->window );
+		return;
+	}
 	pb = gnome_property_box_new();
 
 	gtk_window_set_title(GTK_WINDOW(pb), _("WebControl Properties"));
@@ -242,6 +257,9 @@ properties_cb (AppletWidget *widget, gpointer data)
 
 	gtk_signal_connect(GTK_OBJECT(pb), "apply", GTK_SIGNAL_FUNC(apply_cb),
 			   NULL);
+	gtk_signal_connect(GTK_OBJECT(pb), "destroy",
+			  gtk_widget_destroyed,
+			  (gpointer) &pb);
 
 	gtk_widget_show_all(pb);
 	return;
@@ -249,6 +267,16 @@ properties_cb (AppletWidget *widget, gpointer data)
 	data = NULL;
 }
 
+static void 
+show_help_cb (AppletWidget *applet, gpointer data)
+{
+	static GnomeHelpMenuEntry help_entry = { NULL, "index.html"};
+
+	help_entry.name = gnome_app_id;
+    
+	gnome_help_display (NULL, &help_entry);
+}
+
 /* sesion save signal handler*/
 static gint
 applet_save_session(GtkWidget *w,
@@ -316,15 +344,7 @@ main(int argc, char **argv)
 	gtk_signal_connect(GTK_OBJECT(WC.applet),"save_session",
 			   GTK_SIGNAL_FUNC(applet_save_session),
 			   NULL);
-	
-	/* add an item to the applet menu */
-	applet_widget_register_stock_callback(APPLET_WIDGET(WC.applet),
-					      "about",
-					      GNOME_STOCK_MENU_ABOUT,
-					      _("About..."),
-					      about_cb,
-					      NULL);
-	
+
 	/* add an item to the applet menu */
 	applet_widget_register_stock_callback(APPLET_WIDGET(WC.applet),
 					      "properties",
@@ -332,6 +352,20 @@ main(int argc, char **argv)
 					      _("Properties..."),
 					      properties_cb,
 					      NULL);
+
+	applet_widget_register_stock_callback(APPLET_WIDGET(WC.applet),
+					      "help",
+					      GNOME_STOCK_PIXMAP_HELP,
+					      _("Help"),
+					      show_help_cb,
+					      NULL);
+	
+	applet_widget_register_stock_callback(APPLET_WIDGET(WC.applet),
+					      "about",
+					      GNOME_STOCK_MENU_ABOUT,
+					      _("About..."),
+					      about_cb,
+					      NULL);
 	
 	/* add the widget to the applet-widget, and thereby actually
 	   putting it "onto" the panel */
